@@ -1,4 +1,4 @@
-# Copyright 208-2014 VPAC
+# Copyright 2007-2014 VPAC
 #
 # This file is part of python-alogger.
 #
@@ -23,4 +23,4 @@ from .base import Base
 
 class TestTorque(Base, unittest.TestCase):
     file_prefix = "torque"
-    log_type = "PBS"
+    log_type = "TORQUE"
